@@ -35,7 +35,7 @@ Rcpp::List binaryOptionEngine(std::string binType,
 
 #ifdef QL_HIGH_RESOLUTION_DATE    
     // in minutes
-    boost::posix_time::time_duration length = boost::posix_time::minutes(maturity * 360 * 24 * 60); 
+    boost::posix_time::time_duration length = boost::posix_time::minutes(boost::uint64_t(maturity * 360 * 24 * 60)); 
 #else
     int length = int(maturity*360 + 0.5); // FIXME: this could be better, but same rounding in QL
 #endif
@@ -131,7 +131,7 @@ double binaryOptionImpliedVolatilityEngine(std::string type,
 
 #ifdef QL_HIGH_RESOLUTION_DATE    
     // in minutes
-    boost::posix_time::time_duration length = boost::posix_time::minutes(maturity * 360 * 24 * 60); 
+    boost::posix_time::time_duration length = boost::posix_time::minutes(boost::uint64_t(maturity * 360 * 24 * 60)); 
 #else
     int length = int(maturity*360 + 0.5); // FIXME: this could be better
 #endif
@@ -190,7 +190,7 @@ Rcpp::List barrierOptionEngine(std::string barrType,
 
 #ifdef QL_HIGH_RESOLUTION_DATE    
     // in minutes
-    boost::posix_time::time_duration length = boost::posix_time::minutes(maturity * 360 * 24 * 60); 
+    boost::posix_time::time_duration length = boost::posix_time::minutes(boost::uint64_t(maturity * 360 * 24 * 60)); 
 #else
     int length = int(maturity*360 + 0.5); // FIXME: this could be better
 #endif
